@@ -44,17 +44,18 @@ class Model:
             alpha transparency of voxels if colormap option is chosen. default: opaque colormap (alpha=1)
         
         -- FOR FILE PROCESSING --
+
         file : str
             file name a/or path for goxel txt file
 
         -- FOR XYZ COORDINATE ARRAY PROCESSING -- 
+
         XYZ : np.array(float )
             an array containing the x,y,z coordinates of shape `number_voxel-locations` x 3 [for each x y z]
         RGB : list[str] 
             a list for the colors of every voxels in xyz array (length: `number_voxel-locations`)
         sparsity : float
             a factor to separate the relative distance between each voxel (default:10.0 [> 50.0 may have memory limitations])
-
         '''
         self.array = array          # array of third-order (3-D)
         self.hashblocks = {}        # start with empty voxel-color dictionary
@@ -235,7 +236,7 @@ class Model:
         set_axes_equal(ax)
         plt.show()
 
-    def draw(self, coloring='none', scalars='', background_color='#cccccc', wireframe=False, window_size=[1024, 768]):
+    def draw(self, coloring='none', scalars='', background_color='#cccccc', wireframe=False, window_size=[1024, 768],voxel_spacing=(1,1,1)):
         '''Draws voxel model after building it with the provided `array` with PYVISTA
 
         Parameters
@@ -254,6 +255,8 @@ class Model:
             background color of pyvista plot
         window_size : (float,float)
             defines plot window dimensions. Defaults to [1024, 768], unless set differently in the relevant theme’s window_size property [pyvista.Plotter]
+        voxel_spacing : (float,float,float)
+            changes voxel spacing by defining length scales of x y and z directions (default:(1,1,1)).
         '''
 
         xx, yy, zz, voxid = arr2crds(self.array, -1).T
@@ -267,7 +270,9 @@ class Model:
 
         for i in range(len(centers)):
 
-            voxel = pyvista.Cube(center=centers[i])
+            x_len,y_len,z_len = voxel_spacing
+
+            voxel = pyvista.Cube(center=centers[i],x_length=x_len, y_length=y_len, z_length=z_len)
 
             if coloring == 'voxels':
                 voxel_color, voxel_alpha = self.hashblocks[voxid[i]]
@@ -297,21 +302,19 @@ class Model:
         else:
             toTXT(filename,self.array, self.hashblocks)
 
+        return None
+    
     def load(self, filename='voxeldata.json', coords=False):
-        '''Load to Model object 
-        Data types:
-            .json -> voxel data represented as (DOK) JSON file 
-            .txt -> voxel data represented x,y,z,rgb matrix in .txt file (see Goxel .txt imports)
+        """
+        Load to Model object.
 
         Parameters
         ----------
         filename: string (.json or .txt extensions (see above))
             name of file to be loaded (e.g 'voxeldata.json')
         coords: bool
-            loads and processes  
-            self.XYZ, self.RGB, and self.sparsity = 10.0 (see Model class desc above) to Model if True. 
-            This boolean overrides filename loader option. 
-        '''
+            loads and processes self.XYZ, self.RGB, and self.sparsity = 10.0 (see Model class desc above) to Model if True. This boolean overrides filename loader option. 
+        """
         if coords:
             self.importdata(filename='')
         else:
@@ -332,68 +335,42 @@ class Model:
             else:
                 self.importdata(filename)
 
-    def MarchingMesh(self, level=0,
-            spacing=(1., 1., 1.), gradient_direction='descent', step_size=1, 
-            allow_degenerate=True, method='lewiner', mask=None,
-            plot=False, figsize=(4.8,4.8) ):
-        '''Marching cubes on 3D-mapped image
+    def MarchingMesh(self, level=0,spacing=(1., 1., 1.), gradient_direction='descent', step_size=1, allow_degenerate=True, method='lewiner', mask=None,plot=False, figsize=(4.8,4.8) ):
+        """
+        Marching cubes on 3D mapped image
 
         Parameters
-        ----------
+        ---------------
         voxel_depth : int
             depth of 3-D mapped image on number of voxels
-
-        --- FROM SKIMAGE.MEASURE.MARCHING_CUBES ---
         level : float, optional
-            Contour value to search for isosurfaces in `volume`. If not
-            given or None, the average of the min and max of vol is used.
+            Contour value to search for isosurfaces in `volume`. If not given or None, the average of the min and max of vol is used.
         spacing : length-3 tuple of floats, optional
-            Voxel spacing in spatial dimensions corresponding to numpy array
-            indexing dimensions (M, N, P) as in `volume`.
+            Voxel spacing in spatial dimensions corresponding to numpy array indexing dimensions (M, N, P) as in `volume`.
         gradient_direction : string, optional
-            Controls if the mesh was generated from an isosurface with gradient
-            descent toward objects of interest (the default), or the opposite,
-            considering the *left-hand* rule.
-            The two options are:
-            * descent : Object was greater than exterior
-            * ascent : Exterior was greater than object
-
+            Controls if the mesh was generated from an isosurface with gradient descent toward objects of interest (the default), or the opposite, considering the *left-hand* rule.
+            The two options are: -- descent : Object was greater than exterior -- ascent : Exterior was greater than object
         step_size : int, optional
-            Step size in voxels. Default 1. Larger steps yield faster but
-            coarser results. The result will always be topologically correct
-            though.
+            Step size in voxels. Default 1. Larger steps yield faster but coarser results. The result will always be topologically correct though.
         allow_degenerate : bool, optional
-            Whether to allow degenerate (i.e. zero-area) triangles in the
-            end-result. Default True. If False, degenerate triangles are
-            removed, at the cost of making the algorithm slower.
+            Whether to allow degenerate (i.e. zero-area) triangles in the end-result. Default True. If False, degenerate triangles are removed, at the cost of making the algorithm slower.
         method: str, optional
-            One of 'lewiner', 'lorensen' or '_lorensen'. Specify which of
-            Lewiner et al. or Lorensen et al. method will be used. The
-            '_lorensen' flag correspond to an old implementation that will
-            be deprecated in version 0.19.
+            One of 'lewiner', 'lorensen' or '_lorensen'. Specify which of Lewiner et al. or Lorensen et al. method will be used. The '_lorensen' flag correspond to an old implementation that will be deprecated in version 0.19.
         mask : (M, N, P) array, optional
-            Boolean array. The marching cube algorithm will be computed only on
-            True elements. This will save computational time when interfaces
-            are located within certain region of the volume M, N, P-e.g. the top
-            half of the cube-and also allow to compute finite surfaces-i.e. open
-            surfaces that do not end at the border of the cube.
-
+            Boolean array. The marching cube algorithm will be computed only on True elements. This will save computational time when interfaces are located within certain region of the volume M, N, P-e.g. the top half of the cube-and also allow to compute finite surfaces-i.e. open surfaces that do not end at the border of the cube.
         plot: bool
             plots a preliminary 3-D triangulated image if True
-        '''
-
-        MarchingMesh(self.array, out_file=self.objfile, level=level,
-                spacing=spacing, gradient_direction=gradient_direction, step_size=step_size, 
-                allow_degenerate=allow_degenerate, method=method, mask=mask,
-                plot=plot, figsize=figsize)
+        """
+        MarchingMesh(self.array, out_file=self.objfile, level=level,spacing=spacing, gradient_direction=gradient_direction, step_size=step_size, allow_degenerate=allow_degenerate, method=method, mask=mask, plot=plot, figsize=figsize)
         
         print('mesh created! saved as {}.'.format(self.objfile))
 
     def MeshView(self,wireframe=False,color='pink',alpha=0.5,background_color='#333333', viewport = [1024, 768]):
-        '''
-        MeshView: triangulated mesh view with PyVista 
+        """
+        Triangulated mesh view with PyVista
+
         Parameters
-        ----------
+        --------------
         objfile: string
             .obj file to process with MeshView [in GLOBAL function only]
         wireframe: bool
@@ -406,6 +383,6 @@ class Model:
             color of background. default: 'pink'
         viewport : (int,int)
             viewport / screen (width, height) for display window (default: 80% your screen's width & height)
-        '''
+        """
         mesh = pv.read(self.objfile)
         mesh.plot(show_edges=True if wireframe else False, color=color,opacity=alpha,background=background_color,window_size = viewport)
\ No newline at end of file
